@@ -1,13 +1,10 @@
 #' Search results on a keyword over all fields in PLoS Journals.
 #'
 #' @export
-#' @import ggplot2
-#' @importFrom plyr ldply
-#' 
 #' @param terms search terms (character)
 #' @param vis visualize results in bar plot or not (TRUE or FALSE)
 #' @param ... Optional additional curl options (debugging tools mostly)
-#' 
+#'
 #' @return Number of search results (vis = FALSE), or number of search in a table
 #'    and a histogram of results (vis = TRUE).
 #' @examples \dontrun{
@@ -18,12 +15,13 @@
 #' out[[2]] # results in a bar plot
 #'
 #' # Pass in curl options
+#' library("httr")
 #' plosword('Helianthus', config=verbose())
 #' }
 
-plosword <- function(terms, vis = FALSE, ...)
-{
-  Term=No_Articles=NULL
+plosword <- function(terms, vis = FALSE, ...) {
+  
+  Term <- No_Articles <- NULL
 
   if (length(terms) == 1) {
     setNames(search_(terms, ...), 'Number of articles with search term')
@@ -32,8 +30,8 @@ plosword <- function(terms, vis = FALSE, ...)
     temp$Term <- terms
     temp$Term <- as.character(temp$Term)
     if (vis) {
-      p <- ggplot(temp, aes(x=Term, y=No_Articles)) +
-        geom_bar(stat="identity") +
+      p <- ggplot(temp, aes(x = Term, y = No_Articles)) +
+        geom_bar(stat = "identity") +
         theme_grey(base_size = 18)
       return(list(table = temp, plot = p))
     }
@@ -42,8 +40,8 @@ plosword <- function(terms, vis = FALSE, ...)
 }
 
 search_ <- function(terms, ...){
-  args <- ploscompact(list(q = terms, fl="id", wt="json"))
+  args <- ploscompact(list(q = terms, fl = "id", wt = "json"))
   tt <- GET(pbase(), query = args, ...)
   stop_for_status(tt)
-  jsonlite::fromJSON(content(tt, "text"), FALSE)$response$numFound
+  jsonlite::fromJSON(utf8cont(tt), FALSE)$response$numFound
 }
